%% Function to apply the fitted polynom to data
function F_fit = swift_scheme_extrapolar_apply_fit_monoms(data, monoms, b)
% This function apllies the fitted polynomial to a set of data and yields
% the fitted dOx values.
% INPUT:    data    = matrix [number of data points x 9 o 8 variables]
%                   Each column holds the values of a dependent variable
%                   columns = lat, z, T, topO3, Cly, Bry, NOy, HOy, Ox
%
%           monoms  = matrix [number of monoms x 9 or 8 variables]
%                   Each row represents one monom of the full polynom,
%                   containing the exponent of the variable. If values = 0
%                   this variable is not part of the monom.
%
%           b       = vector [number of monoms], coefficients of monoms.
%                   
% OUTPUT:   F_fit = vector [number of data points], fitted DOx values.
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
assert(size(data,2) == size(monoms,2),...
    'Error in Apply Fit Function: columns of data are unequal columns of monoms.');
% preallocate A
A = zeros(size(data,1), size(monoms,1));
for ii = 1:size(monoms,1)
    % calculate the values of the monoms for each data point, by applying
    % the exponents in monoms to data points and calculating the product of
    % it, 
    A(:,ii) = prod(data.^repmat(monoms(ii,:), size(data,1), 1), 2);
    
end;
% calculate the fitted dOx/Ox values, by folding A with b
F_fit = A*b;