%% Function to apply the gradient of the domain polynom
function [dx] = swift_scheme_extrapolar_calc_gradient(data, polygrad, bgrad)
% Derive the gradient of the monomial matrix of a polynomial
% INPUT:    data = input data [matrix with one column for each dimension]    
%           polygrad = tensor3 containing the exponents of the monomials 
%                   [monomials, dimensions, partial derivative in each dimension]
%           bgrad = matrix with coefficients of the derived monomials per
%           dimension
%           
% OUTPUT:   polygrad = tensor3 with partial derivatives of monom matrix
%           bgrad = matrix with partial derivative coefficient s per column
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
assert(size(polygrad,1) == size(bgrad,1),...
    'Error in swift_scheme_extrapolar_calc_gradient: rows of polygrad are unequal rows of bgrad.');
assert(size(polygrad,2) == size(bgrad,2),...
    'Error in swift_scheme_extrapolar_calc_gradient: columns of polygrad are unequal columns of bgrad.');
assert(size(data,2) == size(polygrad,3),...
    'Error in swift_scheme_extrapolar_calc_gradient: number of layers of polygrad are unequal columns of input data.');

dx1 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,1), bgrad(:,1));
dx2 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,2), bgrad(:,2));
dx3 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,3), bgrad(:,3));
dx4 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,4), bgrad(:,4));
dx5 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,5), bgrad(:,5));
if size(data,2) > 5
    dx6 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,6), bgrad(:,6));
    dx7 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,7), bgrad(:,7));
    dx8 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,8), bgrad(:,8));
    if size(data,2) > 8
        dx9 = swift_scheme_extrapolar_apply_fit_monoms(data, polygrad(:,:,9), bgrad(:,9));

        dx = [dx1,dx2,dx3,dx4,dx5,dx6,dx7,dx8,dx9];
    else
        dx = [dx1,dx2,dx3,dx4,dx5,dx6,dx7,dx8];
    end;
else
    dx = [dx1,dx2,dx3,dx4,dx5];
end;