function ox_out=swift_scheme_extrapolar_chemistry_main(points,overhead,poly_struct,ind,mix_time,current_date)
% Main call to extrapolar SWIFT
% INPUT:    points  = ATLAS points data structure [number of trajectories]
%           overhead = vector [length points] containing the overhead ozone column in DU
%           above the trajectories stroed in points
%           poly_struct = structure containing the extrapolar SWIFT
%           polynomials
%           ind = hard coded indices of SWIFT species (see
%           swift_scheme_get_species_indices.m)
%           mix_time = float [1], ATLAS mixing time step in fraction of day
%           current_date = matlab date [date vector]
%
% OUTPUT:   ox_out = vector [length points], Ox vmr of the next time step.
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lower stratosphere Delta Ox fit
points_lower = points;
no_lower=length(points_lower);

data_lower=NaN(no_lower,9);

% Day of year
% [~,month]=datevec(current_date);
% data_lower(:,1)=ones(no_lower,1)*(current_date-datenum(year,1,1,0,0,0));

% Latitude
data_lower(:,1)=points_lower.latitude;

% Log pressure height
data_lower(:,2)=points_lower.z;

% Temperature
data_lower(:,3)=points_lower.t;

% Overhead ozone
data_lower(:,4)=overhead;

% The chemical families
data_lower(:,5)=points_lower.vmr(ind.Cly);
data_lower(:,6)=points_lower.vmr(ind.Bry);
data_lower(:,7)=points_lower.vmr(ind.NOy);
data_lower(:,8)=points_lower.vmr(ind.H2O); % Use H2O as HOy
data_lower(:,9)=points_lower.vmr(ind.O3);   % Use O3 as Ox

% handle outlier trajectories
data_lower = swift_scheme_extrapolar_prevent_extrapolation(data_lower, poly_struct, current_date, 'full');
%data_lower = swift_scheme_extrapolar_prevent_extrapolation(data_lower, current_date, 'lower');

% Transform overhead ozone to the variable that was fitted
%data_lower(:,5)=exp(-data_lower(:,5)./80);

% calculate the DOx fit value and interpolate between two month
F_fit = swift_scheme_extrapolar_intermonthly_interpolation(data_lower,...
    poly_struct.dox_monom, poly_struct.dox_monom_coef, current_date, 'full');

% Limit max and min DeltaOx ratios 
%F_fit(F_fit>0.3e-6) = 0.3e-6; 
%F_fit(F_fit<-0.3e-6) = -0.3e-6;

% Over write Ox values with Ox values moved back inside the domain
%points_lower.vmr(ind.O3) = data_lower(:,9)+F_fit*mix_time;
% No rubber cell for O3
%points_lower.vmr(ind.O3) = points_lower.vmr(ind.O3)+F_fit*mix_time;
ox_lower = points_lower.vmr(ind.O3)+F_fit*mix_time;

% Temporary hack, until we know why the values explode
%points_lower(points_lower.vmr(ind.O3)<0).vmr(ind.O3)=0;
%points(points.vmr(ind.O3)>20e-6).vmr(ind.O3)=20e-6;
ox_lower(ox_lower<0)=0;

ox_out = ox_lower;