function ox_out = swift_scheme_extrapolar_clim_nudging(points,eqlat,current_date,ind)
% Nudging layer: get points in nudging layer and interpolate (linear) 
% between DOx regime and climatology O3 values.
%
% INPUT:    points  = ATLAS points data structure [number of trajectories]
%           eqlat = vector [length points] equivalent latitude for points     
%           current_date = matlab date [date vector]
%           ind = hard coded indices of SWIFT species (see
%           swift_scheme_get_species_indices.m)
%
% OUTPUT:   ox_out = vector [length points], Ox vmr of the next time step.
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% define lat_grid
lat = [-90:0.5:90]';
no_lat = length(lat);
% extend date to length of lat vector
date = repmat(current_date, no_lat,1);
% calc dox regime altitude 
z_dox = swift_scheme_extrapolar_dyn_upper_boundary(lat, date, 4);
% set thikness of nudging layer
thikness_nudge_layer = 2000;
% define top an low boundary of nudging layer
nudge_boundary_top = z_dox;
nudge_boundary_bot = z_dox - thikness_nudge_layer;
% bin the trajectoires according to latitude
[~, I] = min(abs(repmat(lat, 1, length(points)) - (repmat(points.latitude, 1, length(lat)))'));
% make filter for points in nudging layer
nudge_filter = points.z <= nudge_boundary_top(I) & points.z > nudge_boundary_bot(I);
points_nudge = points(nudge_filter);
eqlat_nudge = eqlat(nudge_filter);
I_nudge = I(nudge_filter);

% linear percentage contribution to nudging layer from climatology
nudge_factor_top = (points_nudge.z - nudge_boundary_bot(I_nudge))/thikness_nudge_layer;
% linear percentage contribution to nudging layer from DOx regime
nudge_factor_bot = 1-nudge_factor_top;

% get O3 climatology values
points_nudge_climO3=init_o3_strat_mls_climatology(points_nudge,eqlat_nudge,current_date);
%points_nudge_climO3=init_daily_strat_atlas_climatology(points_nudge,eqlat_nudge,current_date, 'ox');

% calculate the new Ox VMR, as a contribution from lower and upper regime.
ox_out_nudge = points_nudge.vmr(ind.O3).*nudge_factor_bot + ...
    points_nudge_climO3.*nudge_factor_top;

% Temporary hack, until we know why the values explode
%points_nudge(points_nudge.vmr(ind.O3)<0).vmr(ind.O3)=0;
%points(points.vmr(ind.O3)>20e-6).vmr(ind.O3)=20e-6;

ox_out = points.vmr(ind.O3);
ox_out(nudge_filter) = ox_out_nudge;