function data = swift_scheme_extrapolar_denormalize_fitting_data(data, alt_switch)
% Denormalize the dataset from 0 to 1 to its original physical range. Each
% of the 9 basic SWIFT variables is denormalized by fixed maximum and 
% minimum values, stored in the function get_abs_domain_boundaries.
%
% INPUT:    data        matrix with data normailzed data (from 0 to 1)
%           alt_switch  'lower' 10-32km, 'upper' 28-50km, 'full' 10-50km 
% OUTPUT:   data        denormalized data
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 get_abs_domain_boundaries;
 
 % latitude
 data(:,1) = data(:,1).*(latmax-latmin) + latmin;
 % altitude, switch between different regimes:
 % 'lower' 10-35km, 'upper' 25-50km, 'full' 10-50km
 switch alt_switch
     case 'lower'
        data(:,2) = data(:,2).*(zmax_lower-zmin_lower) + zmin_lower;        
     case 'upper'
        data(:,2) = data(:,2).*(zmax_upper-zmin_upper) + zmin_upper;
     case 'full'  
        data(:,2) = data(:,2).*(zmax_upper-zmin_lower) + zmin_lower;
 end;
 % temperature
 data(:,3) = data(:,3).*(Tmax-Tmin) + Tmin;
 % overhead ozone column
 data(:,4) = data(:,4).*topo3max;
 % Cly
 data(:,5) = data(:,5).*clymax;
 % Bry
 data(:,6) = data(:,6).*brymax;
 % NOy
 data(:,7) = data(:,7).*noymax;
 % HOy
 data(:,8) = data(:,8).*h2omax;
 % Ox
 if size(data,2)>8
    data(:,9) = data(:,9).*oxmax;
 end;