function z_dox = swift_scheme_extrapolar_dyn_upper_boundary(lat, date, order, new_path_to_poly)
% Determine the ATLAS trajectories, which are in the DOx regime and 
% therefore have a Ox lifetime longer than ~14 days.
% Input:    lat = array of latitude [deg]
%           date = array with dates of traj [matlab datenum]
%           order = integer (3-5), order of fit to be used
%
% Output:   out = boolean array, true for traj in DOx regime
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load the polynomial charakterizing the dynamic upper boundary of the DOx
% regime
if nargin==3
    s = load(sprintf('/strat2/data/swift_extrapol/polynom_fit/lifetime/alt_of_lifetime_%ith_order_boa_binned_fit_32500.mat', order));
else
    polynomial_name = sprintf('alt_of_lifetime_%ith_order_boa_binned_fit_32500.mat', order);
    s = load(sprintf('%s/%s',new_path_to_poly, polynomial_name));
end;
% calculate day of year
[cyear , ~]= datevec(date);
doy = date - datenum(cyear-1, 12, 31,0,0,0);
% apply the DOx regime polynomial to latitude grid
z_dox = swift_scheme_extrapolar_apply_fit_monoms([lat, doy], s.accept, s.coeff);