function F_fit = swift_scheme_extrapolar_intermonthly_interpolation(data, monoms, monom_coef, current_date, lower_or_upper)
% This function evaluates 2 polynomials of neighbouring months and 
% interpolates the new Ox vmr linearly between them  to the data
%
% INPUT:    datain  = matrix [length data points x 9] containing the 9 basic
%           SWIFT variables at each data point
%           monoms = exponent matrix of the polynomial terms [number of terms x 9]
%           monoms_coef = vector of coefficients of polynomial terms [number of terms]
%           current_date = matlab date [date vector]
%           lower_or_upper = string setting the altitude range of the 
%           stratosphere either: lower | upper | full
%
% OUTPUT:   F_fit = vector [length data points], interpolated Ox vmr of the next time step.
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% get current year, month and day
[cyear,cmonth,cday]=datevec(current_date);
% create a list of MATLAB date numbers of the 15th of each month (middle of
% month)
% Check if current day is before or after the 15th
if cday>15
    [interp_year, interp_mon] = datevec(current_date + 30);
else
    [interp_year, interp_mon] = datevec(current_date - 30);
end;
% normalize data
data = swift_scheme_extrapolar_normalize_fitting_data(data, lower_or_upper);
% apply DOx fit to current month
F_fit1 = swift_scheme_extrapolar_apply_fit_monoms(data, monoms{cmonth}, monom_coef{cmonth});
%F_fit = F_fit1;

% apply DOx fit to next closest month
F_fit2 = swift_scheme_extrapolar_apply_fit_monoms(data, monoms{interp_mon}, monom_coef{interp_mon});
% Difference in days between "monthly centers"
diffdays = datenum(interp_year, interp_mon, 15) - datenum(cyear, cmonth, 15);
% linear interpolation of fit value to current day
F_fit = F_fit1*(datenum(interp_year,interp_mon,15) - current_date)/diffdays + ...
    F_fit2*(current_date - datenum(cyear,cmonth,15))/diffdays;

