function data = swift_scheme_extrapolar_normalize_fitting_data(data, alt_switch)
% Normalize the dataset to a range from 0 to 1. Each of the 9 basic SWIFT
% variables is normalized by fixed maximum and minimum values, stored in the
% function swift_scheme_extrapolar_get_abs_domain_boundaries.
%
% INPUT:    data        matrix with data to normalize
%           alt_switch  string setting the altitude range of the 
%           stratosphere either: lower | upper | full 
%
% OUTPUT:   data        normalized data from 0 to 1
%
% Author: D. Kreyling, May 2017, original source
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
get_abs_domain_boundaries;

% latitude
data(:,1) = (data(:,1)-latmin)./(latmax - latmin);
% altitude, switch between different regimes:
% 'lower' 10-35km, 'upper' 25-50km, 'full' 10-50km 
switch alt_switch
 case 'lower'
    data(:,2) = (data(:,2)-zmin_lower)./(zmax_lower-zmin_lower);
 case 'upper'
    data(:,2) = (data(:,2)-zmin_upper)./(zmax_upper-zmin_upper); 
 case 'full'
    data(:,2) = (data(:,2)-zmin_lower)./(zmax_upper-zmin_lower);    
end;
% temperature
data(:,3) = (data(:,3)-Tmin)./(Tmax-Tmin);
% overhead ozone column
data(:,4) = data(:,4)./topo3max;
% Cly
data(:,5) = data(:,5)./clymax;
% Bry
data(:,6) = data(:,6)./brymax;
% NOy
data(:,7) = data(:,7)./noymax;
% HOy
data(:,8) = data(:,8)./h2omax;
% Ox
if size(data,2)>8
data(:,9) = data(:,9)./oxmax;
end;
 
% max min level check
%assert((all(data(:)>=0) && all(data(:)<=1)), ...
%    'Normalizing