function [vmr,points_vortex_flag,z_grid_layer_swift,z_grid_level_swift,fap,fas,frac_hno3]=swift_scheme_polar_chemistry_main(points,met,time,time_step,new_model_flag,north_flag)

get_physical_constants;

ind=swift_scheme_get_species_indices;

sza_threshold=90; % Threshold solar zenith angle for daylight

supercooling=3; % Super cooling below Tnat in K

% Threshold value for inside of vortex
if north_flag
  threshold_npv_default=36;
else
  threshold_npv_default=-36; 
end;

%%%%%%%%%%%%%%%%%%%%%
% Levels and layers %
%%%%%%%%%%%%%%%%%%%%%

p_grid_layer_swift=[69.66111 54.03643 41.59872 31.77399 24.07468]; % hPa
z_grid_layer_swift=-H*log(p_grid_layer_swift/p0);
no_layers=length(z_grid_layer_swift);
z_grid_level_swift=0.5*(z_grid_layer_swift(1:end-1)+z_grid_layer_swift(2:end));
z_grid_level_swift=[z_grid_layer_swift(1)-0.5*(z_grid_layer_swift(2)-z_grid_layer_swift(1)) z_grid_level_swift];
z_grid_level_swift=[z_grid_level_swift z_grid_layer_swift(end)+0.5*(z_grid_layer_swift(end)-z_grid_layer_swift(end-1))];

%%%%%%%%%%%%%%%%%%%%%%
% PV and temperature %
%%%%%%%%%%%%%%%%%%%%%%

[no_longitudes,no_latitudes,~]=size(met.t);

met.z=-H*log(met.p/p0);
met.theta=met.t.*(p0./met.p).^(2/7);

tfrac=(time-met.time_grid(1))/(met.time_grid(2)-met.time_grid(1));
pv_iso_tmp=met.pv(:,:,:,1)+(met.pv(:,:,:,2)-met.pv(:,:,:,1))*tfrac;
t_iso_tmp=met.t(:,:,:,1)+(met.t(:,:,:,2)-met.t(:,:,:,1))*tfrac;
z_iso_tmp=met.z(:,:,:,1)+(met.z(:,:,:,2)-met.z(:,:,:,1))*tfrac;
theta_iso_tmp=met.theta(:,:,:,1)+(met.theta(:,:,:,2)-met.theta(:,:,:,1))*tfrac;
npv_iso_tmp=npv(pv_iso_tmp,theta_iso_tmp,475);

normpv=NaN(no_longitudes,no_latitudes,no_layers);
temperature=NaN(no_longitudes,no_latitudes,no_layers);
for layercount=1:no_layers
  normpv(:,:,layercount)=calc_isentrope(z_iso_tmp,npv_iso_tmp,z_grid_layer_swift(layercount));
  temperature(:,:,layercount)=calc_isentrope(z_iso_tmp,t_iso_tmp,z_grid_layer_swift(layercount));  
end;

%%%%%%%
% SZA %
%%%%%%%

[longfield,latfield]=meshgrid(met.long_grid,met.lat_grid);
solar_zenith_angle=sza(time,latfield,longfield)';

%%%%%%%%%%%%%%%%%%%%
% VMR vortex means %
%%%%%%%%%%%%%%%%%%%%

points_npv=npv(points.pv,points.theta,475);

vmr_o3=NaN(no_layers,1);
vmr_hcl=NaN(no_layers,1);
vmr_clono2=NaN(no_layers,1);
vmr_hno3_total=NaN(no_layers,1);
vmr_cly=NaN(no_layers,1);
vmr_h2o=NaN(no_layers,1);

points_vortex_flag=false(size(points.z));

vortex_flag=false(size(normpv));

for layercount=1:no_layers

  % Get the points inside the vortex
  % If the vortex is smaller than a minimum size, set the vortex to a minimum size by
  % changing the threshold value for normalized PV

  [list,threshold_npv]=get_vortex_points(points,points_npv,threshold_npv_default,z_grid_level_swift,north_flag,layercount);

  vmr_o3(layercount)=mean(points(list).vmr(ind.O3));
  vmr_hcl(layercount)=mean(points(list).vmr(ind.HCl));
  vmr_clono2(layercount)=mean(points(list).vmr(ind.ClONO2));
  vmr_hno3_total(layercount)=mean(points(list).vmr(ind.HNO3));
  vmr_cly(layercount)=mean(points(list).vmr(ind.Cly));
  vmr_h2o(layercount)=mean(points(list).vmr(ind.H2O));

  % Set the vortex flag for meteorological data

  if north_flag
    vortex_flag(:,:,layercount)=normpv(:,:,layercount)>threshold_npv;
  else
    vortex_flag(:,:,layercount)=normpv(:,:,layercount)<threshold_npv;
  end;

  % Set the vortex flag for the points variable

  points_vortex_flag(list)=true;

end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Vortex area, FAP and FAS %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Now, calculate vortex area, FAS (fractional area of vortex in sun)
% FAP (fractional area of vortex below threshold temperature for NAT formation)

fap=NaN(no_layers,1);
fap_supercooling=NaN(no_layers,1);
fas=NaN(no_layers,1);

coslat=cos(met.lat_grid*pi/180);

for layercount=1:no_layers
  t_threshold=t_nat(vmr_h2o(layercount),vmr_hno3_total(layercount),p_grid_layer_swift(layercount));
  vortex_area=0;
  nat_area=0;
  nat_supercooling_area=0;
  lit_area=0;
  for longcount=1:no_longitudes
    for latcount=1:no_latitudes
      if vortex_flag(longcount,latcount,layercount)
        vortex_area=vortex_area+coslat(latcount);
        if temperature(longcount,latcount,layercount)<t_threshold
          nat_area=nat_area+coslat(latcount);
        end;
        if temperature(longcount,latcount,layercount)<t_threshold-supercooling
          nat_supercooling_area=nat_supercooling_area+coslat(latcount);
        end;
        lit_list=find(solar_zenith_angle(:,latcount)<sza_threshold);
        lit_area=lit_area+length(lit_list)*coslat(latcount);
      end;
    end;
  end;
  
  fap(layercount)=nat_area/vortex_area;
  fap_supercooling(layercount)=nat_supercooling_area/vortex_area;
  fas(layercount)=lit_area/(no_longitudes*vortex_area);

end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Integrate with 4th order Runge Kutta %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if new_model_flag
  param.a=[79866.1;40852.1;28463.9;24795.5;19636.1];
  param.b=[3.47386e+07;3.03138e+07;2.74027e+07;2.71544e+07;3.77058e+07];
  param.c1=[8.94648e-07;8.36649e-07;7.06846e-07;7.16972e-07;1.10843e-06];
  param.c2=[5.56679e-07;6.38681e-07;6.27474e-07;5.24428e-07;4.9048e-07];
  param.d=[88.8489;83.254;76.4698;69.0419;65.1561];
  param.e=[0.0384692;0.0412464;0.0428536;0.0444329;0.0391818];
  param.f=[0.1863;0.181784;0.180421;0.194049;0.316394];
  param.h=[10306.5;7955.76;5921.15;5002.93;5827.44];
  param.k=[0.0513798;0.0553199;0.0654543;0.0843783;0.121986];
  param.l=[2.24252e+14;1.17627e+14;6.4652e+13;3.51599e+13;1.85954e+13];
  param.z=[0.678851;0.72654;0.756903;0.761521;0.717931];
else
  param.a=1e7*[1.6879;1.3709;0.6947;0.7580;0.9010];
  param.b=[0.0355;0.0373;0.0343;0.0193;0.0135];
  param.c=1e-6*[-0.3046;-0.3689;-0.6323;-0.3272;-0.9030];
  param.d=[90.6576;85.3949;80.8261;84.1327;193.6881];
  param.e=[0.0648;0.0657;0.0463;0.0561;0.0401];
  param.f=[0.7508;0.6873;0.8163;0.0045;-0.5532];
  param.g=[0.0738;0.0870;0.0835;0.0406;0.0120];
  param.h=[0.2131;0.0953;0.0835;0.0175;0.0102];
  param.y=0.110061*ones(no_layers,1);
  param.z=[0.4412;0.5685;0.6476;0.6283;0.3735];
end;

frac_hno3=1+(param.z-1).*fap_supercooling;

dvmr_o3=NaN(no_layers,4);
dvmr_hcl=NaN(no_layers,4);
dvmr_clono2=NaN(no_layers,4);
dvmr_hno3_total=NaN(no_layers,4);

[dvmr_o3(:,1),dvmr_hcl(:,1),dvmr_clono2(:,1),dvmr_hno3_total(:,1)]=swift_ode(vmr_o3, ...
  vmr_hcl, ...
  vmr_clono2, ...
  vmr_hno3_total, ...
  vmr_cly,vmr_h2o,fap,fap_supercooling,fas,param,time_step,north_flag,new_model_flag);

[dvmr_o3(:,2),dvmr_hcl(:,2),dvmr_clono2(:,2),dvmr_hno3_total(:,2)]=swift_ode(vmr_o3+dvmr_o3(:,1)/2, ...
  vmr_hcl+dvmr_hcl(:,1)/2, ...
  vmr_clono2+dvmr_clono2(:,1)/2, ...
  vmr_hno3_total+dvmr_hno3_total(:,1)/2, ...
  vmr_cly,vmr_h2o,fap,fap_supercooling,fas,param,time_step,north_flag,new_model_flag);

[dvmr_o3(:,3),dvmr_hcl(:,3),dvmr_clono2(:,3),dvmr_hno3_total(:,3)]=swift_ode(vmr_o3+dvmr_o3(:,2)/2 , ...
  vmr_hcl+dvmr_hcl(:,2)/2, ...
  vmr_clono2+dvmr_clono2(:,2)/2, ...
  vmr_hno3_total+dvmr_hno3_total(:,2)/2, ...
  vmr_cly,vmr_h2o,fap,fap_supercooling,fas,param,time_step,north_flag,new_model_flag);

[dvmr_o3(:,4),dvmr_hcl(:,4),dvmr_clono2(:,4),dvmr_hno3_total(:,4)]=swift_ode(vmr_o3+dvmr_o3(:,3), ...
  vmr_hcl+dvmr_hcl(:,3), ...
  vmr_clono2+dvmr_clono2(:,3) , ...
  vmr_hno3_total+dvmr_hno3_total(:,3), ...
  vmr_cly,vmr_h2o,fap,fap_supercooling,fas,param,time_step,north_flag,new_model_flag);

dvmr_o3_final=(dvmr_o3(:,1)+2*dvmr_o3(:,2)+2*dvmr_o3(:,3)+dvmr_o3(:,4))/6;
dvmr_hcl_final=(dvmr_hcl(:,1)+2*dvmr_hcl(:,2)+2*dvmr_hcl(:,3)+dvmr_hcl(:,4))/6;
dvmr_clono2_final=(dvmr_clono2(:,1)+2*dvmr_clono2(:,2)+2*dvmr_clono2(:,3)+dvmr_clono2(:,4))/6;
dvmr_hno3_total_final=(dvmr_hno3_total(:,1)+2*dvmr_hno3_total(:,2)+2*dvmr_hno3_total(:,3)+dvmr_hno3_total(:,4))/6;

vmr=points.vmr;

for layercount=1:no_layers

  list=find(points.z>=z_grid_level_swift(layercount)&points.z<z_grid_level_swift(layercount+1)&points_vortex_flag);

  vmr(list,ind.O3)=points(list).vmr(ind.O3)+dvmr_o3_final(layercount);
  vmr(list,ind.HCl)=points(list).vmr(ind.HCl)+dvmr_hcl_final(layercount);
  vmr(list,ind.ClONO2)=points(list).vmr(ind.ClONO2)+dvmr_clono2_final(layercount);
  vmr(list,ind.HNO3)=points(list).vmr(ind.HNO3)+dvmr_hno3_total_final(layercount);

end;

% Avoid negative mixing ratios

zero_list=vmr(:,ind.O3)<0&points_vortex_flag;
vmr(zero_list,ind.O3)=0;
zero_list=vmr(:,ind.HCl)<0&points_vortex_flag;
vmr(zero_list,ind.HCl)=0;
zero_list=vmr(:,ind.ClONO2)<0&points_vortex_flag;
vmr(zero_list,ind.ClONO2)=0;
zero_list=vmr(:,ind.HNO3)<0&points_vortex_flag;
vmr(zero_list,ind.HNO3)=0;

% Two limiters to avoid that HCl or ClONO2 are greater than Cly

hcl_list=vmr(:,ind.HCl)>vmr(:,ind.Cly)&points_vortex_flag;
vmr(hcl_list,ind.HCl)=vmr(hcl_list,ind.Cly);

clono2_list=vmr(:,ind.ClONO2)>vmr(:,ind.Cly)&points_vortex_flag;
vmr(clono2_list,ind.ClONO2)=vmr(clono2_list,ind.Cly);

% Limiter: Sum of HCl and ClONO2 must be smaller than Cly, else ClOx will be negative

sum_list=vmr(:,ind.Cly)<(vmr(:,ind.ClONO2)+vmr(:,ind.HCl))&points_vortex_flag;
ratio=vmr(sum_list,ind.Cly)./(vmr(sum_list,ind.ClONO2)+vmr(sum_list,ind.HCl));
vmr(sum_list,ind.ClONO2)=vmr(sum_list,ind.ClONO2).*ratio;
vmr(sum_list,ind.HCl)=vmr(sum_list,ind.HCl).*ratio;



function [dvmr_o3,dvmr_hcl,dvmr_clono2,dvmr_hno3_total]=swift_ode(vmr_o3,vmr_hcl,vmr_clono2,vmr_hno3_total,vmr_cly,vmr_h2o,fap,fap_supercooling,fas,param,time_step,north_flag,new_model_flag)

% Same limiters as above

vmr_o3(vmr_o3<0)=0;
vmr_hcl(vmr_hcl<0)=0;
vmr_clono2(vmr_clono2<0)=0;
vmr_hno3_total(vmr_hno3_total<0)=0;

vmr_hcl(vmr_hcl>vmr_cly)=vmr_cly(vmr_hcl>vmr_cly);
vmr_clono2(vmr_clono2>vmr_cly)=vmr_cly(vmr_clono2>vmr_cly);

sum_list=vmr_cly<vmr_hcl+vmr_clono2;
ratio=vmr_cly./(vmr_hcl+vmr_clono2);
vmr_clono2(sum_list)=vmr_clono2(sum_list).*ratio(sum_list);
vmr_hcl(sum_list)=vmr_hcl(sum_list).*ratio(sum_list);

if new_model_flag
  hcl_threshold=1E-12;

  vmr_clox=vmr_cly-vmr_hcl-vmr_clono2;
  vmr_hno3_gas=(1+(param.z-1).*fap_supercooling).*vmr_hno3_total;

  term_oh_day=fas;

  term_clo_day=vmr_clox;

  term_cl2o2_day=vmr_clox;

  term_hocl=term_clo_day.*fas;

  term_a=param.a.*vmr_clono2.*vmr_hno3_total.^(2/3).*fap;
  list=(vmr_hcl<hcl_threshold);
  term_a(list)=term_a(list).*vmr_hcl(list)/hcl_threshold;

  term_b=param.b.*vmr_clox.*vmr_hno3_gas.*fas;

  term_c=param.c1.*fas.*fas.*term_cl2o2_day./vmr_o3+ ...
         param.c2.*fas.*fas.*fas.*vmr_clono2./vmr_o3;

  term_d=param.d.*vmr_clox.*fas;

  term_e=param.e.*vmr_hno3_total.*fap_supercooling;

  term_f=param.f.*term_clo_day.*term_oh_day.*fas;

  term_h=param.h.*vmr_clono2.*vmr_hno3_total.^(2/3).*fap;

  term_k=param.k.*vmr_hcl.*term_oh_day.*fas;

  term_l=param.l.*term_hocl.*vmr_hcl.*vmr_hno3_total.^(2/3).*fap;

  % A special limiter for Term A to deplete same amount of HCl and ClONO2 in this reaction
  % even when the increment is larger than the vmr. Term A is the ugliest one in term of time scales

  list=find(term_a*time_step>min(vmr_hcl,vmr_clono2));
  term_a(list)=min(vmr_hcl(list),vmr_clono2(list))/time_step;

  dvmr_o3         = -term_d*time_step;
  dvmr_clono2     = (term_b-term_a-term_h)*time_step;
  dvmr_hcl        = (term_c+term_f-term_a-term_l-term_k)*time_step;
  dvmr_hno3_total = -term_e*time_step;
else
  clox_threshold=0.05*2.7E-9;
  hcl_threshold=0.01*2.7E-9;

  vmr_clox=vmr_cly-vmr_hcl-vmr_clono2;
  vmr_hno3_gas=(1+(param.z-1).*fap_supercooling).*vmr_hno3_total;

  term_a=param.a.*vmr_clono2.*vmr_hno3_total.*fap;
  list=(vmr_hcl<hcl_threshold);
  term_a(list)=term_a(list).*vmr_hcl(list)/hcl_threshold;

  term_b=param.b.*vmr_hno3_gas.*fas;
  list=(vmr_clox<clox_threshold);
  term_b(list)=term_b(list).*vmr_clox(list)/clox_threshold;

  term_c=param.c.*vmr_clox.*fas./vmr_o3;

  term_d=param.d.*vmr_clox.*fas;

  term_e=param.e.*vmr_hno3_total.*fap_supercooling;

  term_f=param.f.*vmr_clox.*fas.*fas;
  if ~north_flag
    term_f=term_f.*0.25;
  end;

  term_g=param.g.*vmr_clono2.*fas;

  term_h=param.h.*vmr_clono2.*max(fap-param.y,0);

  % A special limiter for Term A to deplete same amount of HCl and ClONO2 in this reaction
  % even when the increment is larger than the vmr. Term A is the ugliest one in term of time scales

  list=find(term_a*time_step>min(vmr_hcl,vmr_clono2));
  term_a(list)=min(vmr_hcl(list),vmr_clono2(list))/time_step;

  dvmr_o3         = -term_d*time_step;
  dvmr_clono2     = (term_b-term_a-term_g-term_h)*time_step;
  dvmr_hcl        = (term_c+term_f-term_a)*time_step;
  dvmr_hno3_total = -term_e*time_step;
end;

function [list_vortex,threshold_npv]=get_vortex_points(points,points_npv,threshold_npv,z_grid_level_swift,north_flag,layercount)

% Calculate a list of the points in the vortex

% If the vortex is smaller than a minimum vortex area (given as the fraction of the earth surface area)
% change the threshold value for normalized PV so that the vortex is big enough

earth_area_fraction=0.01;

list_all=find(points.z>=z_grid_level_swift(layercount)&points.z<z_grid_level_swift(layercount+1));
 
if north_flag
  list_vortex=find(points.z>=z_grid_level_swift(layercount)&points.z<z_grid_level_swift(layercount+1)&points_npv>threshold_npv);
  if (length(list_vortex)/length(list_all))<earth_area_fraction
    sortnpv=sort(points_npv(list_all));
    threshold_npv=sortnpv(fix((1-earth_area_fraction)*length(sortnpv)));
    list_vortex=find(points.z>=z_grid_level_swift(layercount)&points.z<z_grid_level_swift(layercount+1)&points_npv>threshold_npv);
  end;
else
  list_vortex=find(points.z>=z_grid_level_swift(layercount)&points.z<z_grid_level_swift(layercount+1)&points_npv<threshold_npv);
  if (length(list_vortex)/length(list_all))<earth_area_fraction
    list=find(points.z>=z_grid_level_swift(layercount)&points.z<z_grid_level_swift(layercount+1));
    sortnpv=sort(points_npv(list_all));
    threshold_npv=sortnpv(fix(earth_area_fraction*length(sortnpv)));
    list_vortex=find(points.z>=z_grid_level_swift(layercount)&points.z<z_grid_level_swift(layercount+1)&points_npv<threshold_npv);
  end;
end;
